﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using Xamarin.Forms;

namespace SyncFusion
{
    public class ChartListView : ContentPage
    {
        public ObservableCollection<MyChartData> listviewData;
        ListView listView;

        public ChartListView(bool isRecycle = true)
        {
            listviewData = new ObservableCollection<MyChartData>();

            listView = new ListView(isRecycle ? ListViewCachingStrategy.RecycleElement : ListViewCachingStrategy.RetainElement)
            {
                ItemsSource = listviewData,
                HasUnevenRows = true,
                SeparatorVisibility = SeparatorVisibility.None,
                ItemTemplate = new DataTemplate(() => {
                    StackLayout layout = new StackLayout { BackgroundColor = Color.White };

                    Label lblTitle = new Label();
                    lblTitle.TextColor = Color.Black;
                    lblTitle.BackgroundColor = Color.White;
                    lblTitle.SetBinding(Label.TextProperty, "Title");
                    lblTitle.HorizontalTextAlignment = TextAlignment.Center;
                    layout.Children.Add(lblTitle);

                    var chart = new SfChart
                    {
                        HeightRequest = 200,
                        HorizontalOptions = LayoutOptions.FillAndExpand,
                        VerticalOptions = LayoutOptions.FillAndExpand,
                        PrimaryAxis = new CategoryAxis(),
                        SecondaryAxis = new NumericalAxis
                        {
                            Minimum = 0,
                            Maximum = 100,
                            Interval = 20,
                        },
                    };

                    /*
                    chart.ChartBehaviors.Add(new ChartZoomPanBehavior()
                    {
                        EnableSelectionZooming = true,
                    });
                    */

                    chart.Legend = new ChartLegend
                    {
                        ToggleSeriesVisibility = true,
                    };
                    chart.SetBinding(SfChart.SeriesProperty, "Series");

                    layout.Children.Add(chart);

                    return new ViewCell
                    {
                        View = new Frame
                        {
                            Padding = 5,
                            Content = layout,
                        },
                    };
                }),
            };

            listView.ItemSelected += (object sender, SelectedItemChangedEventArgs e) => {
                listView.SelectedItem = null;
            };

            Content = listView;
            Title = isRecycle ? "Recycle ListView" : "ListView";
        }

        protected override void OnAppearing()
        {
            base.OnAppearing();
            Device.StartTimer(TimeSpan.FromSeconds(1), () =>
            {
                if(listviewData != null)
                    LoadItems();

                return false;
            });

        }


        public void LoadItems()
        {
            if (listView == null) return;

            try
            {
                listView.IsRefreshing = true;

                var ageGroup = new List<string> { "Under 25", "30-35", "36-40", "41-45", "above 45" };
                var rating5  = new List<string> { "1", "2", "3", "4", "5" };
                var firstVisit = new List<string> { "TV", "Radio", "NewsPaper", "SocialMedia", "Ad" };

                //#1
                MakeChartData(rating5);

                //#2
                MakeChartData(ageGroup);

                //#3
                MakeChartData(rating5);

                //#4
                MakeChartData(rating5);

                //#5
                MakeChartData(firstVisit);

                //#6
                MakeChartData(rating5);

                //#7
                MakeChartData(rating5);

                listView.IsRefreshing = false;
            }
            catch (Exception ex)
            {
                listView.IsRefreshing = false;
            }
        }

        public void MakeChartData(List<string> responses)
        {
            try
            {
                string title = string.Empty;
                ChartSeriesCollection series = new ChartSeriesCollection();
                Random rnd1 = new Random();
                foreach (var key in responses.OrderBy(k => k.Length).ThenBy(c => c))
                {
                        ObservableCollection<ChartDataPoint> Data = new ObservableCollection<ChartDataPoint>();
                       
                        foreach (var loc in new List<string> { "London", "Tokyo", "India" })
                        {
                            Data.Add(new ChartDataPoint(loc, rnd1.Next(0,100)));
                        }

                        series.Add(new ColumnSeries()
                        {
                            ItemsSource = Data,
                            //EnableTooltip = true,
                            Color = Color.Default,
                            Label = key,
                            DataMarker = new ChartDataMarker
                            {
                                LabelStyle = new DataMarkerLabelStyle
                                {
                                    Margin = new Thickness(5),
                                    TextColor = Color.White,
                                },
                            },
                        });
                    }

                    listviewData.Add(new MyChartData { Title = title, Series = series });

            }
            catch (Exception ex)
            {

            }
        }
    }

    //My Chart
    public class MyChartData
    {
        public string Title { get; set; }
        public string xAxisLabel { get; set; }
        public string yAxisLabel { get; set; }
        public ChartSeriesCollection Series { get; set; }
    }

    }
